@@ -22,8 +22,5 @@ class SPDeviceFilterForm(DeviceFilterForm):
     ]
 
     rack_role = DynamicModelMultipleChoiceField(
-        queryset=RackRole.objects.all(),
-        required=False,
-        label="Rack role",
-        widget=APISelectMultiple(null_option=True,),
+        queryset=RackRole.objects.all(), required=False, label="Rack role",
     )
